Package: timbr
Type: Package
Title: Forest/Tree Data Frames
Version: 0.2.2
Authors@R: 
    person(
        given = "Mizuki", 
        family = "Uchida", 
        email = "uchidamizuki@vivaldi.net", 
        role = c("aut", "cre")
    )
Description: Provides data frames for forest or tree data structures. You can 
    create forest data structures from data frames and process them based on 
    their hierarchies.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.2.3
Imports: cli, dplyr, lifecycle, memoise, pillar, purrr, rlang, tibble,
        tidygraph, vctrs (>= 0.5.2)
Suggests: covr, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/UchidaMizuki/timbr,
        https://uchidamizuki.github.io/timbr/
BugReports: https://github.com/UchidaMizuki/timbr/issues
NeedsCompilation: no
Packaged: 2023-04-29 10:13:13 UTC; Mizuki
Author: Mizuki Uchida [aut, cre]
Maintainer: Mizuki Uchida <uchidamizuki@vivaldi.net>
Repository: CRAN
Date/Publication: 2023-04-29 10:40:02 UTC
Built: R 4.4.0; ; 2024-05-05 12:42:11 UTC; unix
