# Generated by roxygen2: do not edit by hand

S3method(as_forest,grouped_df)
S3method(as_forest,rowwise_df)
S3method(as_tbl_graph,forest)
S3method(as_tibble,forest)
S3method(format,forest)
S3method(format,timbr_node)
S3method(group_data,forest)
S3method(group_indices,forest)
S3method(group_keys,forest)
S3method(group_size,forest)
S3method(group_vars,forest)
S3method(groups,forest)
S3method(mutate,forest)
S3method(n_groups,forest)
S3method(pillar_shaft,timbr_node)
S3method(print,forest)
S3method(rbind,forest)
S3method(relocate,forest)
S3method(rows_patch,forest)
S3method(rows_update,forest)
S3method(rowwise,forest)
S3method(select,forest)
S3method(summarise,forest)
S3method(tbl_format_header,tbl_forest)
S3method(tbl_sum,tbl_forest)
S3method(ungroup,forest)
S3method(vec_ptype_abbr,timbr_node)
export(as_forest)
export(children)
export(climb)
export(forest_by)
export(is_forest)
export(leaves)
export(map_forest)
export(node_name)
export(node_parent)
export(node_value)
export(traverse)
import(vctrs)
importFrom(dplyr,group_data)
importFrom(dplyr,group_indices)
importFrom(dplyr,group_keys)
importFrom(dplyr,group_size)
importFrom(dplyr,group_vars)
importFrom(dplyr,groups)
importFrom(dplyr,mutate)
importFrom(dplyr,n_groups)
importFrom(dplyr,relocate)
importFrom(dplyr,rows_patch)
importFrom(dplyr,rows_update)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(pillar,pillar_shaft)
importFrom(pillar,tbl_format_header)
importFrom(pillar,tbl_sum)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(tibble,as_tibble)
importFrom(tidygraph,as_tbl_graph)
